@@ -1,6 +1,6 @@
 /*
 --             This file is part of the New World OS project
---                 Copyright (C) 2006-2007  QRW Software
+--                 Copyright (C) 2006-2008  QRW Software
 --           J. Scott Edwards - j.scott.edwards.nwos@gmail.com 
 --                      http://www.qrwsoftware.com
 --                      http://nwos.sourceforge.com
@@ -27,6 +27,12 @@
 --
 --
 -- $Log: disk_usage.c,v $
+-- Revision 1.23  2008/04/02 03:06:21  jsedwards
+-- Added file locking.
+--
+-- Revision 1.22  2008/02/03 01:15:40  jsedwards
+-- Change to use nwos_get_private_objects_path function instead of DEFAULT_FILE.
+--
 -- Revision 1.21  2007/11/03 14:12:31  jsedwards
 -- Rearranged chunk/block output table yet again.
 --
@@ -135,6 +141,7 @@
 */
 
 
+#include <errno.h>
 #include <fcntl.h>
 #include <stdio.h>
 #include <stdlib.h>
@@ -243,6 +250,8 @@ uint32 calculate_blocks_used(int obj_fd, uint32 start, Chunk_Info chunk_info[],
 int main(int argc, char* argv[])
 {
     int obj_file_desc;
+    struct flock lock;
+    const char* obj_file_path;
     char ref_str[128];
     uint32 reserved_private_blocks;
     uint32 used_private_blocks;
@@ -283,18 +292,30 @@ int main(int argc, char* argv[])
 	}
     }
 
+    obj_file_path = nwos_get_private_objects_path();
 
-    obj_file_desc = open(DEFAULT_FILE, O_RDONLY);
+    obj_file_desc = open(obj_file_path, O_RDONLY);
 
     if (obj_file_desc < 0)
     {
-	perror(DEFAULT_FILE);
+	perror(obj_file_path);
+	exit(1);
+    }
+
+    lock.l_type = F_RDLCK;
+    lock.l_whence = SEEK_SET;
+    lock.l_start = 0;
+    lock.l_len = 0;
+
+    if (fcntl(obj_file_desc, F_SETLK, &lock) != 0)
+    {
+	perror(obj_file_path);
 	exit(1);
     }
 
     if (read(obj_file_desc, block, sizeof(block)) != sizeof(block))
     {
-	snprintf(ref_str, sizeof(ref_str), "reading disk header from: %s", DEFAULT_FILE);
+	snprintf(ref_str, sizeof(ref_str), "reading disk header from: %s", obj_file_path);
 	perror(ref_str);
 	exit(1);
     }
@@ -336,7 +357,7 @@ int main(int argc, char* argv[])
 
     if (read(obj_file_desc, chunk_info, sizeof_chunk_info) != sizeof_chunk_info)
     {
-	snprintf(ref_str, sizeof(ref_str), "reading chunk_info from: %s", DEFAULT_FILE);
+	snprintf(ref_str, sizeof(ref_str), "reading chunk_info from: %s", obj_file_path);
 	perror(ref_str);
 	exit(1);
     }
