@@ -27,6 +27,10 @@
 --
 --
 -- $Log: expand_sparse.c,v $
+-- Revision 1.31  2008/07/19 13:15:33  jsedwards
+-- If 0'd out printing of every block's reference ID so it doesn't spew every
+-- block ID to the screen anymore.  Added calls to print a progress bar instead.
+--
 -- Revision 1.30  2008/06/04 14:03:15  jsedwards
 -- Added code to alert user to run the 'update_files_0028' program if
 -- compressed file is older than 0028.
@@ -342,8 +346,12 @@ int main(int argc, char* argv[])
 
     bytes_read = fread(block, 1, FILE_BLOCK_SIZE, ifp);
 
+    nwos_start_progress_bar();
+
     while (bytes_read == FILE_BLOCK_SIZE)
     {
+	nwos_update_progress_bar((float)num_blocks / (float)used_private_blocks);
+
 	nwos_4_uint8_to_uint32(&block[4], &ref);
 
 	hash = nwos_hash_uint32_ref(ref);
@@ -357,8 +365,11 @@ int main(int argc, char* argv[])
 	    assert(hash != 0);
 	}
 
+#if 0  
+	/*************** save this for a verbose mode? *************/
 	printf("id: %08x  block: %08x\n", ref, hash);
 	fflush(stdout);
+#endif
 
 	if (nwos_test_bit_in_map(hash))
 	{
@@ -377,6 +388,8 @@ int main(int argc, char* argv[])
 	bytes_read = fread(block, 1, FILE_BLOCK_SIZE, ifp);
     }
 
+    nwos_finish_progress_bar();
+
     if (ferror(ifp))
     {
 	perror(argv[1]);
