@@ -27,6 +27,10 @@
 --
 --
 -- $Log: import_file.c,v $
+-- Revision 1.37  2008/07/13 14:18:58  jsedwards
+-- Feature Request #1856369 - Added handling of new IMPORTED_DATA result from
+-- nwos_create_file.
+--
 -- Revision 1.36  2008/07/11 13:01:05  jsedwards
 -- Added include of limits.h to define PATH_MAX.
 --
@@ -348,6 +352,10 @@ void process_file(const char* path, Add_Revision_Type add_revision, bool do_recu
 		       (int) (time(NULL) - start_time));
 		break;
 
+	      case IMPORTED_DATA:
+		printf("imported data: %02x%02x%02x%02x\n", ref.id[0], ref.id[1], ref.id[2], ref.id[3]);
+		break;
+
 	      case CREATED_NEW_REVISION:
 		printf("file created: %02x%02x%02x%02x   time: %d seconds\n", 
 		       ref.id[0], ref.id[1], ref.id[2], ref.id[3], 
@@ -589,6 +597,7 @@ int main(int argc, char* argv[])
     }
 
     printf("files created:   %d\n", result_counts[CREATED_NEW]);
+    printf("imported data:   %d\n", result_counts[IMPORTED_DATA]);
     printf("new revisions:   %d\n", result_counts[CREATED_NEW_REVISION]);
     printf("new paths:       %d\n", result_counts[CREATED_NEW_PATH_FOR_EXISTING_FILE]);
     printf("existing files:  %d\n", result_counts[FOUND_EXISTING]);
