@@ -27,6 +27,17 @@
 --
 --
 -- $Log: objectify.h,v $
+-- Revision 1.143  2008/07/19 11:26:23  jsedwards
+-- Added external declarations for progress bar functions.
+--
+-- Revision 1.142  2008/07/17 12:05:53  jsedwards
+-- Moved ObjCreateResult enum earlier in the file, before the function
+-- declarations, and changed nwos_find_or_create_private_class_definition to
+-- return ObjCreateResult instead of void.
+--
+-- Revision 1.141  2008/07/13 14:06:50  jsedwards
+-- Added IMPORTED_DATA to ObjCreateResult enumeration.
+--
 -- Revision 1.140  2008/06/22 18:57:06  jsedwards
 -- Changed nwos_normalize_path to return void instead of bool.
 --
@@ -882,6 +893,8 @@ static inline uint32 byteswap_uint32(uint32 x)
 typedef enum { Public_Reference, Private_Reference } Reference_Type;
 typedef enum { Security_None=0, Security_Minimal, Security_Very_Low, Security_Low, Security_Medium, Security_High, Security_Extreme } Security_Level;
 
+typedef enum { CREATED_NEW, IMPORTED_DATA, CREATED_NEW_REVISION, FOUND_EXISTING, ERROR_OCCURRED, DUPLICATE_PATH, DUPLICATE_FILE, PATH_NOT_FOUND, MULTIPLE_FILES, CREATED_NEW_PATH_FOR_EXISTING_FILE, NUM_OBJ_RESULTS } ObjCreateResult;
+
 
 /* These functions aren't standard */
 #ifndef HAVE_STRLCPY
@@ -940,7 +953,7 @@ extern void nwos_remove_from_reference_list(ObjRef* ref, ObjRef* ref_list);
 //extern bool nwos_find_class_definition(char* name, ObjRef* class_ref);
 extern bool nwos_find_public_class_definition(char* name, ObjRef* class_ref);
 extern bool nwos_find_private_class_definition(char* name, ObjRef* class_ref);
-extern void nwos_find_or_create_private_class_definition(char* name_of_class, ObjRef* ref);
+extern ObjCreateResult nwos_find_or_create_private_class_definition(char* name_of_class, ObjRef* ref);
 extern bool nwos_find_public_feature_definition(ObjRef* type_ref, char* name, int count, ObjRef* feat_ref);
 extern void nwos_find_or_create_public_feature_definition(ObjRef* type_ref, char* name, int count, ObjRef* feat_ref);
 
@@ -952,9 +965,6 @@ extern void nwos_read_object_from_disk(ObjRef* ref, void* object, size_t size);
 extern void nwos_read_variable_sized_object_from_disk(ObjRef* ref, void* obj, size_t max_size, size_t (*size_function)(void*));
 extern void nwos_read_reference_list_from_disk(ObjRef* ref, ReferenceList* object, size_t size);
 
-typedef enum { CREATED_NEW, CREATED_NEW_REVISION, FOUND_EXISTING, ERROR_OCCURRED, DUPLICATE_PATH, DUPLICATE_FILE, PATH_NOT_FOUND, MULTIPLE_FILES, CREATED_NEW_PATH_FOR_EXISTING_FILE, NUM_OBJ_RESULTS } ObjCreateResult;
-
-
 
 /* word stuff */
 extern bool nwos_find_language(char* name, ObjRef* ref);
@@ -1095,6 +1105,11 @@ extern bool nwos_is_valid_ssn(const char* ssn);
 
 extern void nwos_get_key_from_password(uint8 key[], size_t key_size);
 
+extern void nwos_start_progress_bar();
+extern void nwos_update_progress_bar(float percent);  /* 0.0 <= percent < 1.0 */
+extern void nwos_finish_progress_bar();
+
+
 /* currently the largest object is a disc list */
 #define MAX_OBJECT_BLOCKS ((MAX_SIZE_DISC_LIST + FILE_BLOCK_SIZE - 1) / FILE_BLOCK_SIZE)
 #define MAX_OBJECT_SIZE (MAX_OBJECT_BLOCKS * FILE_BLOCK_SIZE)
