@@ -27,6 +27,10 @@
 --
 --
 -- $Log: objectify_private.h,v $
+-- Revision 1.68  2008/07/19 13:33:16  jsedwards
+-- Added external declarations for new disk_io_is_read_only and
+-- disk_io_is_read_write functions in disk_io.c file.
+--
 -- Revision 1.67  2008/06/26 14:50:26  jsedwards
 -- Changed nwos_initialize_backup to return bool instead of void.
 --
@@ -487,6 +491,8 @@ extern void nwos_write_object_to_disk_and_encrypt(ObjRef* ref, void* object, siz
 extern const char* nwos_public_path;
 extern const char* nwos_private_path;
 extern void  nwos_initialize_disk_io(AccessType type, const char* path);
+extern bool  nwos_disk_io_is_read_only();
+extern bool  nwos_disk_io_is_read_write();
 extern void  nwos_terminate_disk_io();
 extern bool  nwos_initialize_backup(const char* path, Disk_Header* disk_header);
 extern void  nwos_terminate_backup(bool modified, Disk_Header* disk_header);
