@@ -27,6 +27,10 @@
 --
 --
 -- $Log: user_config.c,v $
+-- Revision 1.13  2008/06/08 16:33:08  jsedwards
+-- Added #ifdef HTTP around code that tries to open a config file in the user's
+-- home directory, because when running under apache $HOME isn't defined.
+--
 -- Revision 1.12  2008/02/24 13:24:33  jsedwards
 -- Fix so that if DEFAULT_USER_CONFIG_PATH contains a leading '~' the user's
 -- home directory will correctly be substituted.
@@ -126,7 +130,7 @@ const char* get_users_home_dir(const char* path)
 
 static void read_configuration_file()
 {
-    FILE* fp;
+    FILE* fp = NULL;
     char config_path[PATH_MAX];
     char buffer[1024];
     int line_number = 0;
@@ -150,6 +154,7 @@ static void read_configuration_file()
 
 	/* then read the file */
 
+#ifndef HTTP
 	/* first try to open a users config file */
 	if (*DEFAULT_USER_CONFIG_PATH == '~')
 	{
@@ -162,6 +167,7 @@ static void read_configuration_file()
 	}
 
 	fp = fopen(config_path, "r");
+#endif
 
 	/* if that failed try to open the system config file */
 	if (fp == NULL)
